DetectDocumentTextResponse class

Constructors

DetectDocumentTextResponse({List<Block>? blocks, String? detectDocumentTextModelVersion, DocumentMetadata? documentMetadata})
DetectDocumentTextResponse.fromJson(Map<String, dynamic> json)
factory

Properties

blocks → List<Block>?
An array of Block objects that contain the text that's detected in the document.
final
detectDocumentTextModelVersion → String?
final
documentMetadata → DocumentMetadata?
Metadata about the document. It contains the number of pages that are detected in the document.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited