GetDocumentTextDetectionResponse class

Constructors

GetDocumentTextDetectionResponse({List<Block>? blocks, String? detectDocumentTextModelVersion, DocumentMetadata? documentMetadata, JobStatus? jobStatus, String? nextToken, String? statusMessage, List<Warning>? warnings})
GetDocumentTextDetectionResponse.fromJson(Map<String, dynamic> json)
factory

Properties

blocks → List<Block>?
The results of the text-detection operation.
final
detectDocumentTextModelVersion → String?
final
documentMetadata → DocumentMetadata?
Information about a document that Amazon Textract processed. DocumentMetadata is returned in every page of paginated responses from an Amazon Textract video operation.
final
hashCode → int
The hash code for this object.
no setterinherited
jobStatus → JobStatus?
The current status of the text detection job.
final
nextToken → String?
If the response is truncated, Amazon Textract returns this token. You can use this token in the subsequent request to retrieve the next set of text-detection results.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusMessage → String?
Returns if the detection job could not be completed. Contains explanation for what error occured.
final
warnings → List<Warning>?
A list of warnings that occurred during the text-detection operation for the document.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited