HumanLoopDataAttributes class

Allows you to set attributes of the image. Currently, you can declare an image as free of personally identifiable information and adult content.

Constructors

HumanLoopDataAttributes({List<ContentClassifier>? contentClassifiers})

Properties

contentClassifiers → List<ContentClassifier>?
Sets whether the input image is free of personally identifiable information or adult content.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited