NotificationChannel class

The Amazon Simple Notification Service (Amazon SNS) topic to which Amazon Textract publishes the completion status of an asynchronous document operation, such as StartDocumentTextDetection.

Constructors

NotificationChannel({required String roleArn, required String sNSTopicArn})

Properties

hashCode → int
The hash code for this object.
no setterinherited
roleArn → String
The Amazon Resource Name (ARN) of an IAM role that gives Amazon Textract publishing permissions to the Amazon SNS topic.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sNSTopicArn → String
The Amazon SNS topic that Amazon Textract posts the completion status to.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited