OutputConfig class

Sets whether or not your output will go to a user created bucket. Used to set the name of the bucket, and the prefix on the output file.

Constructors

OutputConfig({required String s3Bucket, String? s3Prefix})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3Bucket → String
The name of the bucket your output will go to.
final
s3Prefix → String?
The prefix of the object key that the output will be saved to. When not enabled, the prefix will be “textract_output".
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited