Warning class

A warning about an issue that occurred during asynchronous text analysis (StartDocumentAnalysis) or asynchronous document text detection (StartDocumentTextDetection).

Constructors

Warning({String? errorCode, List<int>? pages})
Warning.fromJson(Map<String, dynamic> json)
factory

Properties

errorCode → String?
The error code for the warning.
final
hashCode → int
The hash code for this object.
no setterinherited
pages → List<int>?
A list of the pages that the warning applies to.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited